/* -------------------------- ARANDOM.H -------------------------------
; Function prototypes for random number generators
;
; 32-bit mode version for 80x86 and compatible microprocessors.
; Works with Window 95 and later, and possibly with other 32-bit systems.
;
; The theory of these random number generators is explained at
; www.agner.org/random
;
;----------------------------------------------------------------------
;
; WRandom uses the RANROT type W algorithm with self-test.
; The resolution is 63 bits for WRandom and 32 bits for WBRandom.
;
; The random number generator must be initialized by calling
; WRandomInit with a random seed before the first call to WRandom,
; WBRandom or WIRandom.
; WRandom returns a floating point number between 0 and 1.
; WBRandom returns an integer between 0 and 0xFFFFFFFF
; WIRandom returns an integer in the interval set by WSetInterval
;
;----------------------------------------------------------------------
;
; MRandom uses the Mother-of-All algorithm with 32 bits resolution.
; The random number generator must be initialized by calling
; MRandomInit with a random seed before the first call to MRandom.
; MRandom returns a floating point number between 0 and 1.
;
;---------------------------------------------------------------------
;
; XRandom combines the RANROT type W and the Mother-of-All generators.
; This gives the best possible randomness for the most demanding
; applications. The resolution is 63 bits for XRandom.
;
; The random number generator must be initialized by calling
; XRandomInit with a random seed before the first call to XRandom
; or XIRandom.
;
; XRandom returns a floating point number between 0 and 1.
; XIRandom returns an integer in the interval set by XSetInterval.
;
----------------------------------------------------------------------- */
                                                                              
extern"C" void     _cdecl WRandomInit (int seed);
extern"C" void     _cdecl WSetInterval (int min, int max);
extern"C" double   _cdecl WRandom  (void);
extern"C" unsigned _cdecl WBRandom (void);
extern"C" int      _cdecl WIRandom (void);

extern"C" void     _cdecl MRandomInit (int seed);
extern"C" double   _cdecl MRandom (void);

extern"C" void     _cdecl XRandomInit (int seed);
extern"C" void     _cdecl XSetInterval (int min, int max);
extern"C" double   _cdecl XRandom (void);
extern"C" int      _cdecl XIRandom (void);

